resultSetStore.BdbResultSetStore

|  | ## Cheshire3 Object Model: Class BdbResultSetStore

Module resultSetStore :: Class BdbResultSetStore

## Class BdbResultSetStore
source code

Object Tree:

               object --+
                        |
    configParser.C3Object --+
                            |
                  ObjectStore --+
                                |
       baseObjects.ResultSetStore --+
                                    |
                 SimpleResultSetStore --+
                                        |
                   object --+           |
                            |           |
        configParser.C3Object --+       |
                                |       |
                      SimpleStore --+   |
                                    |   |
                   baseStore.BdbStore --+
                                        |
                                       BdbResultSetStore

Known Subclasses:
  BdbResultSetStore2

Instance Methods

__init__(self, session, parent, config) The constructor for all Cheshire3 objects take the same arguments: session: A Session object topNode: The <config> or <subConfig> domNode for the configuration parent: The object that provides the scope for this object.
create_resultSet(self, session, rset=None)
delete_resultSet(self, session, rsid)
fetch_resultSet(self, session, rsid)
fetch_resultSetList(self, session)
store_resultSet(self, session, rset)
clean(self, session)
Inherited from `SimpleResultSetStore`: `generate_id` Inherited from `SimpleResultSetStore` (private): `_verifyDefault` Inherited from `baseObjects.ObjectStore`: `create_object`, `delete_object`, `fetch_object`, `store_object` Inherited from `baseStore.BdbStore`: `__iter__`, `begin_storing`, `commit_storing`, `delete_item`, `fetch_checksum`, `fetch_data`, `fetch_idList`, `fetch_size`, `get_dbsize`, `store_checkSum`, `store_data`, `verify_checkSum` Inherited from `baseStore.BdbStore` (private): `_closeContainer`, `_initialise`, `_openContainer`, `_verifyDatabase`, `_verifyDatabases` Inherited from `configParser.C3Object`: `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_handleConfigNode`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

cxn |
txn |
Inherited from `SimpleResultSetStore`: `databaseHash`, `databaseHashReverse`, `storeHash`, `storeHashReverse` Inherited from `baseStore.BdbStore`: `digestCxn`, `digestForId` Inherited from `baseStore.SimpleStore`: `currentId`, `idNormalizer` Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### __init__(self, session, parent, config) (Constructor) | source code
The constructor for all Cheshire3 objects take the same arguments: session: A Session object topNode: The <config> or <subConfig> domNode for the configuration parent: The object that provides the scope for this object. Overrides: SimpleResultSetStore.__init__

### create_resultSet(self, session, rset=None) | source code
Overrides: baseObjects.ResultSetStore.create_resultSet

### delete_resultSet(self, session, rsid) | source code
Overrides: baseObjects.ResultSetStore.delete_resultSet

### fetch_resultSet(self, session, rsid) | source code
Overrides: baseObjects.ResultSetStore.fetch_resultSet

### fetch_resultSetList(self, session) | source code
Overrides: baseObjects.ResultSetStore.fetch_resultSetList

### store_resultSet(self, session, rset) | source code
Overrides: baseObjects.ResultSetStore.store_resultSet

### clean(self, session) | source code
Overrides: baseStore.BdbStore.clean

Class Variable Details

    ### cxn Value:
        None

    ### txn Value:
        None